<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
<context>
    <name>NetFileChooseEdit</name>
    <message>
        <source>All files (*)</source>
        <translation>Todos los archivos (*)</translation>
    </message>
</context>
<context>
    <name>NetPasswordEdit</name>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
</context>
<context>
    <name>PageAirplane</name>
    <message>
        <source>Airplane mode</source>
        <translation>Modo avión</translation>
    </message>
    <message>
        <source>Stop wireless communication</source>
        <translation>Detener comunicación inalámbrica</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>Activar el modo avión apagara la red inalámbrica, la zona wifi y Bluetooth</translation>
    </message>
</context>
<context>
    <name>PageAppProxy</name>
    <message>
        <source>Application Proxy</source>
        <translation>Aplicación Proxy</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurar servidores proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>http</source>
        <translation>http</translation>
    </message>
    <message>
        <source>socks4</source>
        <translation>socks4</translation>
    </message>
    <message>
        <source>socks5</source>
        <translation>socks5</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Puerto inválido</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Una vez configurado, active la opción &quot;Usar un proxy&quot; haciendo clic derecho sobre las aplicaciones en el lanzador.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>PageDSL</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>Set up a dial-up network connection</source>
        <translation>Configurar conexión de red telefónica</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add PPPoE connection</source>
        <translation>Añadir conexión PPPoE</translation>
    </message>
</context>
<context>
    <name>PageDSLSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propiedades de red</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>¿Está seguro que desea borrar la configuración?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>PageDetails</name>
    <message>
        <source>Network Details</source>
        <translation>Detalles de red</translation>
    </message>
    <message>
        <source>View all network configurations</source>
        <translation>Ver todas las configuraciones de red</translation>
    </message>
    <message>
        <source>Details has been copied</source>
        <translation>Se han copiado los detalles</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleccionar todo</translation>
    </message>
    <message>
        <source>Network Detection</source>
        <translation>Detección de red</translation>
    </message>
</context>
<context>
    <name>PageHotspot</name>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Sin enlazar</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Zona wifi</translation>
    </message>
    <message>
        <source>Share the network</source>
        <translation>Compartir red</translation>
    </message>
    <message>
        <source>My Hotspot</source>
        <translation>Mi zona wifi</translation>
    </message>
    <message>
        <source>Edit My Hotspot</source>
        <translation>Editar mi zona wifi</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nombre (SSID)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <source>Shared Settings</source>
        <translation>Ajustes compartidos</translation>
    </message>
    <message>
        <source>Hotspot Sharing Device</source>
        <translation>Dispositivo para zona wifi</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable Airplane Mode first and then enable the wireless network adapter.</source>
        <translation>Si desea utilizar la zona wifi, primero desactive el modo avión y luego active el adaptador de red inalámbrica.</translation>
    </message>
    <message>
        <source>If you want to use the personal hotspot, disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first and then enable the wireless network adapter.</source>
        <translation>Si desea utilizar la zona wifi, primero desactive el &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;modo avión&lt;/a&gt; y luego active el adaptador de red inalámbrica.</translation>
    </message>
</context>
<context>
    <name>PageSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propiedades de red</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>¿Está seguro que desea borrar la configuración?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>PageSystemProxy</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
    <message>
        <source>Set up proxy servers</source>
        <translation>Configurar servidores proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>URL de configuración</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>Proxy HTTP</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>Proxy HTTPS</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>Proxy FTP</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>Proxy SOCKS</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Ignorar las configuraciones de proxy para los hosts y dominios anteriores</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>PageVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Connect, add, import</source>
        <translation>Conectar, añadir, importat</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add VPN</source>
        <translation>Añadir VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importar VPN</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Error al importar</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Error en el archivo</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceptar</translation>
    </message>
</context>
<context>
    <name>PageVPNSettings</name>
    <message>
        <source> Network Properties</source>
        <translation>Propiedades de red</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>Tipo de VPN</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>¿Está seguro que desea borrar la configuración?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>*.conf</source>
        <translation>*.conf</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>PageWiredDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Conectar, editar ajustes de red</translation>
    </message>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Conecte en el cable de red primero</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Añadir conexión de red</translation>
    </message>
</context>
<context>
    <name>PageWirelessDevice</name>
    <message>
        <source>Connect, edit network settings</source>
        <translation>Conectar, editar ajustes de red</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Desconectar</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Conectar</translation>
    </message>
    <message>
        <source>My Networks</source>
        <translation>Mis redes</translation>
    </message>
    <message>
        <source>Other Networks</source>
        <translation>Otras redes</translation>
    </message>
    <message>
        <source>Disable Airplane Mode first if you want to connect to a wireless network</source>
        <translation>Si desea conectarse a una red inalámbrica, primero desactive el modo avión </translation>
    </message>
    <message>
        <source>Disable &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Si desea conectarse a una red inalámbrica, primero desactive el &lt;a style=&apos;text-decoration: none;&apos; href=&apos;network/airplaneMode&apos;&gt;modo avión&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Desactive la zona wifi si desea conectarse a una red inalámbrica</translation>
    </message>
    <message>
        <source>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Disable hotspot&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>&lt;a style=&apos;text-decoration: none;&apos; href=&apos;NetHotspotControlItem&apos;&gt;Desactive la zona wifi&lt;/a&gt; si desea conectarse a una red inalámbrica</translation>
    </message>
</context>
<context>
    <name>SectionDNS</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Finalizar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
</context>
<context>
    <name>SectionDevice</name>
    <message>
        <source>Not Bind</source>
        <translation>Sin enlazar</translation>
    </message>
    <message>
        <source>WLAN</source>
        <translation>WLAN</translation>
    </message>
    <message>
        <source>Ethernet</source>
        <translation>Ethernet</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Dirección MAC del dispositivo</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Dirección MAC clonada</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Personalizar el MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Banda</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>2.4 GHz</source>
        <translation>2.4 GHz</translation>
    </message>
    <message>
        <source>5 GHz</source>
        <translation>5 GHz</translation>
    </message>
</context>
<context>
    <name>SectionGeneric</name>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nombre (SSID)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nombre</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Conectar automáticamente</translation>
    </message>
</context>
<context>
    <name>SectionIPv4</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Finalizar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Solo aplicable a los recursos correspondientes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Máscara de red</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de red inválida</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dirección IP duplicada</translation>
    </message>
</context>
<context>
    <name>SectionIPv6</name>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automático</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Finalizar</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Método</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Solo aplicable a los recursos correspondientes</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>Dirección IP</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Dirección IP inválida</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Prefijo</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Máscara de red inválida</translation>
    </message>
    <message>
        <source>Duplicate IP address</source>
        <translation>Dirección IP duplicada</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
</context>
<context>
    <name>SectionPPP</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bit MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE con estado</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Negar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Negar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Negar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Negar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Negar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sin compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sin compresión de datos por deflación</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sin compresión en cabecera TCP</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes eco PPP</translation>
    </message>
</context>
<context>
    <name>SectionPPPOE</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servicio</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>SectionSecret</name>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>TLS en túnel</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>EAP protegido</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>GTC</source>
        <translation>GTC</translation>
    </message>
    <message>
        <source>MSCHAPV2</source>
        <translation>MSCHAPV2</translation>
    </message>
    <message>
        <source>PAP</source>
        <translation>PAP</translation>
    </message>
    <message>
        <source>MSCHAP</source>
        <translation>MSCHAP</translation>
    </message>
    <message>
        <source>CHAP</source>
        <translation>CHAP</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Personal</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Enterprise</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Personal</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP Auth</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Identidad</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opciones de contraseña</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Guardar la contraseña para este usuario</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Guardar la contraseña para todos los usuarios</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Pregúntarme siempre</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Clave</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autenticación</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Clave compartida</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Sistema abierto</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>ID anónimo</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Provisionamiento</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anónimo</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Autenticado</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Ambos</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>Archivo PAC</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>Versión PEAP</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automático </translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versión 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versión 1</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Autenticación interna</translation>
    </message>
</context>
<context>
    <name>SectionVPN</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Todos los archivos (*)</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Puerta de enlace inválida</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Puerta de enlace</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>Certificado CA</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Permitir el troyano Cisco Secure Desktop</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>Script CSD</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Tipo de autenticación</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Clave privada</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>Agente SSH</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Tarjeta inteligente</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Clave precompartida</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Certificado de usuario</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Usar FSID para la frase de clave</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Certificados (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Certificados con contraseña (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Clave estática</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Opciones de contraseña</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Preguntar</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>No requerido</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Contraseña privada</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Personalizar dirección de clave</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Dirección de clave</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>IP remota</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>IP local</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>Dominio NT</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Solicitar una dirección IP interna</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Forzar encapsulación UDP</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Usar compresión IP</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Activar propuestas de cifrado personalizadas </translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Nombre del grupo</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Contraseña de grupo</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Usar autenticación híbrida</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>Archivo CA</translation>
    </message>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Usar MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Seguridad</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Todos disponibles (por defecto)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (menos seguro)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (más seguro)</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>MPPE con estado</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Negar autenticación EAP</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Negar autenticación PAP</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Negar autenticación CHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Negar autenticación MSCHAP</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Negar autenticación MSCHAPv2</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Sin compresión de datos BSD</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Sin compresión de datos por deflación</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Sin compresión en cabecera TCP</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Sin compresión en el campo de protocolo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Sin compresión de dirección y control</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Enviar paquetes eco PPP</translation>
    </message>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Activar IPsec</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>ID de grupo</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Algoritmos de Fase1</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Algoritmos de Fase2</translation>
    </message>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN Avanzado</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Personalizar puerto de la puerta de enlace</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Puerto de puerta de enlace</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Personalizar intervalo de renegociación</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Intervalo de renegociación</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Utilizar compresión LZO</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Usar conexión TCP</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Usar dispositivo TAP</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Personalizar túnel MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Personalizar tamaño del fragmento UDP</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>Tamaño del fragmento UDP</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Restringir el túnel TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Aleatorizar hosts remotos</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Proveedor</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (por defecto)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Seguro (por defecto)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Débil</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>Modo de recorrido NAT</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T si está disponible (por defecto)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T siempre</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>Grupo IKE DH</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH Grupo 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH Grupo 2 (por defecto)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Grupo 5</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Reenvío secreto</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Servidor (por defecto)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Grupo 2</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Puerto local</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Desactivar detección de pares muertos</translation>
    </message>
    <message>
        <source>VPN Security</source>
        <translation>Seguridad VPN</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Cifrado</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Por defecto</translation>
    </message>
    <message>
        <source>DES-CBC</source>
        <translation>DES-CBC</translation>
    </message>
    <message>
        <source>RC2-CBC</source>
        <translation>RC2-CBC</translation>
    </message>
    <message>
        <source>DES-EDE-CBC</source>
        <translation>DES-EDE-CBC</translation>
    </message>
    <message>
        <source>DES-EDE3-CBC</source>
        <translation>DES-EDE3-CBC</translation>
    </message>
    <message>
        <source>DESX-CBC</source>
        <translation>DESX-CBC</translation>
    </message>
    <message>
        <source>BF-CBC</source>
        <translation>BF-CBC</translation>
    </message>
    <message>
        <source>RC2-40-CBC</source>
        <translation>RC2-40-CBC</translation>
    </message>
    <message>
        <source>CAST5-CBC</source>
        <translation>CAST5-CBC</translation>
    </message>
    <message>
        <source>RC2-64-CBC</source>
        <translation>RC2-64-CBC</translation>
    </message>
    <message>
        <source>AES-128-CBC</source>
        <translation>AES-128-CBC</translation>
    </message>
    <message>
        <source>AES-192-CBC</source>
        <translation>AES-192-CBC</translation>
    </message>
    <message>
        <source>AES-256-CBC</source>
        <translation>AES-256-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-128-CBC</source>
        <translation>CAMELLIA-128-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-192-CBC</source>
        <translation>CAMELLIA-192-CBC</translation>
    </message>
    <message>
        <source>CAMELLIA-256-CBC</source>
        <translation>CAMELLIA-256-CBC</translation>
    </message>
    <message>
        <source>SEED-CBC</source>
        <translation>SEED-CBC</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Auth</translation>
    </message>
    <message>
        <source>RSA MD-4</source>
        <translation>RSA MD-4</translation>
    </message>
    <message>
        <source>MD-5</source>
        <translation>MD-5</translation>
    </message>
    <message>
        <source>SHA-1</source>
        <translation>SHA-1</translation>
    </message>
    <message>
        <source>SHA-224</source>
        <translation>SHA-224</translation>
    </message>
    <message>
        <source>SHA-256</source>
        <translation>SHA-256</translation>
    </message>
    <message>
        <source>SHA-384</source>
        <translation>SHA-384</translation>
    </message>
    <message>
        <source>SHA-512</source>
        <translation>SHA-512</translation>
    </message>
    <message>
        <source>RIPEMD-160</source>
        <translation>RIPEMD-160</translation>
    </message>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN Proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Tipo de proxy</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>IP del servidor</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Si falla reintentar indefinidamente </translation>
    </message>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>Autenticación TLS VPN</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Coincidir nombres</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Tipo de certificado remoto</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Cliente</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Servidor</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Archivo de clave</translation>
    </message>
</context>
<context>
    <name>SystemProxyConfigItem</name>
    <message>
        <source>Optional</source>
        <translation>Opcional</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Puerto</translation>
    </message>
    <message>
        <source>Authentication is required</source>
        <translation>Autenticación requerida</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nombre de usuario</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Requerido</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Contraseña</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Si desea conectarse a una red inalámbrica, primero desactive el &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;modo avión&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflicto de IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation>Conexión cableada %1</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>Conexión PPPoE %1</translation>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation>Conectando %1</translation>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation>&quot;%1&quot; conectado</translation>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation>&quot;%1&quot; desconectado</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor, compruebe el router o el cable de red.</translation>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation>No se puede conectar &quot;%1&quot;, por favor manténgase cerca del enrutador inalámbrico</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation>Fallo de conexión, no se puede conectar &quot;%1&quot;, contraseña incorrecta</translation>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation>Se requiere una contraseña para conectarse &quot;%1&quot;</translation>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation>No se puede encontrar la red WLAN 802.11 &quot;%1&quot; </translation>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation>Para conectar &quot;%1&quot;, configure su información de autenticación después de iniciar sesión</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation>Proxy del sistema</translation>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation>La configuración de VPN no está conectada o falló al conectar. Por favor&lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;acceda a el centro de control&lt;/a&gt; para inspeccion.</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Red cableada</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Red inalámbrica</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Conectarse a una red oculta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Mis redes</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Otras redes</translation>
    </message>
</context>
<context>
    <name>network</name>
    <message>
        <source>Network</source>
        <translation>Red</translation>
    </message>
</context>
</TS>